@@ -66,18 +66,8 @@ namespace Kross {
 
 using namespace Kross;
 
-PythonExtension::PythonExtension(QObject* object, bool owner)
-    : Py::PythonExtension<PythonExtension>()
-    , d( new Private() )
+void PythonExtension::init_type()
 {
-    d->object = object;
-    d->owner = owner;
-
-    #ifdef KROSS_PYTHON_EXTENSION_CTORDTOR_DEBUG
-        d->debuginfo = object ? QString("%1 (%2)").arg(object->objectName()).arg(object->metaObject()->className()) : "NULL";
-        krossdebug( QString("PythonExtension::Constructor object=%1").arg(d->debuginfo) );
-    #endif
-
     behaviors().name("KrossPythonExtension");
     behaviors().doc("The KrossPythonExtension object wraps a QObject into the world of python.");
     //behaviors().supportPrint();
@@ -108,10 +98,23 @@ PythonExtension::PythonExtension(QObject* object, bool owner)
     //add_varargs_method("__fromPointer__", &PythonExtension::fromPointer, "Set the QObject* to the passed void* pointer.");
     add_varargs_method("connect", &PythonExtension::doConnect, "Connect signal, slots or python functions together.");
     add_varargs_method("disconnect", &PythonExtension::doDisconnect, "Disconnect signal, slots or python functions that are connected together.");
+}
+
+PythonExtension::PythonExtension(QObject* object, bool owner)
+    : Py::PythonExtension<PythonExtension>()
+    , d( new Private() )
+{
+    d->object = object;
+    d->owner = owner;
+
+    #ifdef KROSS_PYTHON_EXTENSION_CTORDTOR_DEBUG
+        d->debuginfo = object ? QString("%1 (%2)").arg(object->objectName()).arg(object->metaObject()->className()) : "NULL";
+        krossdebug( QString("PythonExtension::Constructor object=%1").arg(d->debuginfo) );
+    #endif
 
     d->proxymethod = new Py::MethodDefExt<PythonExtension>(
         "", // methodname, not needed cause we use the method only internaly.
-        0, // method that should handle the callback, not needed cause proxyhandler will handle it.
+        Py::MethodDefExt<PythonExtension>::method_varargs_function_t( 0 ), // method that should handle the callback, not needed cause proxyhandler will handle it.
         Py::method_varargs_call_handler_t( proxyhandler ), // callback handler
         "" // documentation
     );
@@ -669,7 +672,7 @@ PyObject* PythonExtension::proxyhandler(PyObject *_self_and_name_tuple, PyObject
     return Py_None;
 }
 
-int PythonExtension::sequence_length()
+PyCxx_ssize_t PythonExtension::sequence_length()
 {
     return d->object->children().count();
 }
@@ -717,7 +720,7 @@ int PythonExtension::sequence_ass_slice(Py_ssize_t from, Py_ssize_t to, const Py
     throw Py::RuntimeError( QString("Unsupported: PythonExtension::sequence_ass_slice %1 %2 %3").arg(from).arg(to).arg(obj.as_string().c_str()).toLatin1().constData() );
 }
 
-int PythonExtension::mapping_length()
+PyCxx_ssize_t PythonExtension::mapping_length()
 {
     return d->object->children().count();
 }
